@@ -6,9 +6,9 @@
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,11 +16,11 @@
 # limitations under the License.
 #
 
-require 'mixlib/log'
+require "mixlib/log"
 
 module Mixlib
   module Authentication
-    DEFAULT_SERVER_API_VERSION = '0'
+    DEFAULT_SERVER_API_VERSION = "0"
 
     class AuthenticationError < StandardError
     end
@@ -29,12 +29,10 @@ module Mixlib
     end
 
     class Log
-      extend  Mixlib::Log      
+      extend Mixlib::Log
     end
-    
+
     Log.level = :error
-    
+
   end
 end
-
-
