@@ -6,9 +6,9 @@
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# 
+#
 #     http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,15 +16,15 @@
 # limitations under the License.
 #
 
-require 'mixlib/authentication'
-require 'openssl'
+require "mixlib/authentication"
+require "openssl"
 
 module Mixlib
   module Authentication
     class Digester
       class << self
 
-        def hash_file(f, digest=OpenSSL::Digest::SHA1)
+        def hash_file(f, digest = OpenSSL::Digest::SHA1)
           digester = digest.new
           buf = ""
           while f.read(16384, buf)
@@ -37,7 +37,7 @@ module Mixlib
         #
         # ====Parameters
         #
-        def hash_string(str, digest=OpenSSL::Digest::SHA1)
+        def hash_string(str, digest = OpenSSL::Digest::SHA1)
           ::Base64.encode64(digest.digest(str)).chomp
         end
 
